| Title: | SMTrackR: an R/Bioconductor package for mapping protein binding at individual DNA molecules |
|---|---|
| Description: | The package uses exogenous enzyme imprinted information to map protein-DNA binding on individual sequenced DNA molecules. For example, GpC methyltransferase, CpG methyltransferase, and Adenine methyltransferases. Public datasets from such assays are compiled into tracks, and hosted at public servers like Galaxy for their seamless access by this package. |
| Authors: | Aashna Bansal [aut, ctb], Himani Barmola [aut, ctb], Shivam Yadav [aut, ctb], Satyanarayan Rao [aut, cre] (ORCID: <https://orcid.org/0000-0001-7678-3505>) |
| Maintainer: | Satyanarayan Rao <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.1.0 |
| Built: | 2026-06-04 07:15:27 UTC |
| Source: | https://github.com/bioc/SMTrackR |
Generates Gviz-compatible R code that puts SMF footprints below ideogram and genetracks. This call assumes that you have already ran 'plotFootprints' function. Designed for Drosophila melanogaster analysis with expandable parameters for other organisms.
generateGvizCodeforSMF( organism = "demlanogaster", model = "S2", condition = "WT", genome_assembly = "dm6", type = "dSMF", chromosome = "chr2L", start = 480290, end = 480320, tr = "fp_and_mvec", label = "peak229", span_left = 150, span_right = 150, remove_dup = FALSE, fp_cap = 50, gviz_left = 1000, gviz_right = 1000, target_dir = "" )generateGvizCodeforSMF( organism = "demlanogaster", model = "S2", condition = "WT", genome_assembly = "dm6", type = "dSMF", chromosome = "chr2L", start = 480290, end = 480320, tr = "fp_and_mvec", label = "peak229", span_left = 150, span_right = 150, remove_dup = FALSE, fp_cap = 50, gviz_left = 1000, gviz_right = 1000, target_dir = "" )
organism |
Organism code (default: "dmelanogaster") |
model |
Biological model/system (default: "S2" cells) |
condition |
Experimental condition (default: "WT") |
genome_assembly |
Genome version (default: "dm6") |
type |
Data type ("dSMF" = dual enzyme Single Molecule Footprinting) |
chromosome |
Chromosome ID (e.g., "chr2L") |
start |
Genomic start position (numeric/character) |
end |
Genomic end position (numeric/character) |
tr |
Track name for BigBed file resource (default: "fp_and_mvec") |
label |
Plot title annotation |
span_left |
Upstream window size from region (default: 150) |
span_right |
Downstream window size from region (default: 150) |
remove_dup |
Remove duplicate reads? (default: FALSE) |
fp_cap |
Maximum footprint value for y-axis scaling (default: 50) |
gviz_left |
left zoom (bases) from the start |
gviz_right |
right zoom (bases) from the end |
target_dir |
destination directory (must be the same used in 'plotFootprints' function) |
This function generates a R code running which one can get ideogram, genetracks and SMF heatmap altogether in one plot.
Saves a heatmap in pdf, png, and eps file formats.
# Basic usage with default parameters generateGvizCodeforSMF(organism = "mmusculus", model = "16cell", condition = "WT", genome_assembly = "mm10", type = "SMF", chromosome = "chr1",start = 191718250, end = 191718280, tr = "16cell", label = "tss", fp_cap = 50, remove_dup = FALSE, gviz_left = 500, gviz_right = 500, target_dir = "")# Basic usage with default parameters generateGvizCodeforSMF(organism = "mmusculus", model = "16cell", condition = "WT", genome_assembly = "mm10", type = "SMF", chromosome = "chr1",start = 191718250, end = 191718280, tr = "16cell", label = "tss", fp_cap = 50, remove_dup = FALSE, gviz_left = 500, gviz_right = 500, target_dir = "")
Retrieves track metadata from a centralized Google Sheet containing organism-specific single-molecule datasets and experimental conditions.
listTracks()listTracks()
A tibble containing track metadata with columns:
organism: Species identifier (e.g. "dmelanogaster")
genome_assembly: Reference genome version
condition: Experimental condition
model: Biological model/system
track_name: Identifier for 'tr' parameter in 'plotFootprints'
data_type: NOME-seq protocol variant
bigbed_url: Cloud-hosted data location
'plotFootprints()': Use track names from this list to visualize specific datasets
# List all available tracks from default repository listTracks()# List all available tracks from default repository listTracks()
Generates footprint plots from NOME-seq data within specified genomic regions. Designed for Drosophila melanogaster analysis with expandable parameters for other organisms.
plotFootprints( organism = "dmelanogaster", model = "S2", condition = "WT", genome_assembly = "dm6", type = "dSMF", chromosome = "chr2L", start = 480290, end = 480320, tr = "fp_and_mvec", label = "peak229", span_left = 150, span_right = 150, remove_dup = FALSE, fp_cap = 50, target_dir = "" )plotFootprints( organism = "dmelanogaster", model = "S2", condition = "WT", genome_assembly = "dm6", type = "dSMF", chromosome = "chr2L", start = 480290, end = 480320, tr = "fp_and_mvec", label = "peak229", span_left = 150, span_right = 150, remove_dup = FALSE, fp_cap = 50, target_dir = "" )
organism |
Organism code (default: "dmelanogaster") |
model |
Biological model/system (default: "S2" cells) |
condition |
Experimental condition (default: "WT") |
genome_assembly |
Genome version (default: "dm6") |
type |
Data type ("dSMF" = dual enzyme Single Molecule Footprinting) |
chromosome |
Chromosome ID (e.g., "chr2L") |
start |
Genomic start position (numeric/character) |
end |
Genomic end position (numeric/character) |
tr |
Track name for BigBed file resource (default: "fp_and_mvec") |
label |
Plot title annotation |
span_left |
Upstream window size from region (default: 150) |
span_right |
Downstream window size from region (default: 150) |
remove_dup |
Remove duplicate reads? (default: FALSE) |
fp_cap |
Maximum footprint value for y-axis scaling (default: 50) |
target_dir |
destination directory where outputs will be stored |
This function retrieves and visualizes DNA accessibility patterns from single-molecule data: - Integrates with UCSC-style track hubs via 'tr' parameter - Automatically handles coordinate conversion for dm6 genome - Implements dynamic y-axis scaling using 'fp_cap'
Saves a heatmap in pdf, png, and eps file formats. Also, occupancies are saved in a tsv file
# Basic usage with default parameters plotFootprints() # Custom genomic region analysis plotFootprints( chromosome = "chr2L", start = 480290, end = 480320, label = "peak229")# Basic usage with default parameters plotFootprints() # Custom genomic region analysis plotFootprints( chromosome = "chr2L", start = 480290, end = 480320, label = "peak229")
Generates footprint plots from SMF/dSMF data within specified genomic regions. Designed for Drosophila melanogaster analysis with expandable parameters for other organisms.
plotFootprintsUsingLocalBigBed( bigBed = "", organism = "dmelanogaster", model = "S2", condition = "WT", genome_assembly = "dm3", chromosome = "chr2L", start = 480290, end = 480320, label = "peak229", span_left = 150, span_right = 150, remove_dup = FALSE, fp_cap = 50, target_dir = "" )plotFootprintsUsingLocalBigBed( bigBed = "", organism = "dmelanogaster", model = "S2", condition = "WT", genome_assembly = "dm3", chromosome = "chr2L", start = 480290, end = 480320, label = "peak229", span_left = 150, span_right = 150, remove_dup = FALSE, fp_cap = 50, target_dir = "" )
bigBed |
BigBed file path (e.g., "demo.bb") |
organism |
Organism code (default: "dmelanogaster") |
model |
Biological model/system (default: "S2" cells) |
condition |
Experimental condition (default: "WT") |
genome_assembly |
Genome version (default: "dm6") |
chromosome |
Chromosome ID (e.g., "chr2L") |
start |
Genomic start position (numeric/character) |
end |
Genomic end position (numeric/character) |
label |
Plot title annotation |
span_left |
Upstream window size from region (default: 150) |
span_right |
Downstream window size from region (default: 150) |
remove_dup |
Remove duplicate reads? (default: FALSE) |
fp_cap |
Maximum footprint value for y-axis scaling (default: 50) |
target_dir |
destination directory where outputs will be stored |
This function uses local SMF/dSMF bigBed file and plot heatmap
Saves a heatmap in pdf, png, and eps file formats. Also, occupancies are saved in a tsv file
# Basic usage with default parameters plotFootprintsUsingLocalBigBed() # Custom genomic region analysis plotFootprintsUsingLocalBigBed( bigBed = "inst/extdata/demo.bb", organism = "dmelanogaster", model = "S2", condition = "WT", genome_assembly = "dm3", chromosome = "chr2L", start = 480290, end = 480320, label = "peak229")# Basic usage with default parameters plotFootprintsUsingLocalBigBed() # Custom genomic region analysis plotFootprintsUsingLocalBigBed( bigBed = "inst/extdata/demo.bb", organism = "dmelanogaster", model = "S2", condition = "WT", genome_assembly = "dm3", chromosome = "chr2L", start = 480290, end = 480320, label = "peak229")
Generates footprint plots from NOME-seq data within specified genomic regions. Designed for Drosophila melanogaster analysis with expandable parameters for other organisms.
plotMethylationCallsNanopore( organism = "scerevisiae", model = "BY4741 strain", condition = "WT", genome_assembly = "sacCer3", type = "SMF", chromosome = "chrIII", start = 114300, end = 114600, tr = "nanopore_meth_calls", label = "smac_seq", span_left = 1000, span_right = 1000, stride = 5, target_dir = "" )plotMethylationCallsNanopore( organism = "scerevisiae", model = "BY4741 strain", condition = "WT", genome_assembly = "sacCer3", type = "SMF", chromosome = "chrIII", start = 114300, end = 114600, tr = "nanopore_meth_calls", label = "smac_seq", span_left = 1000, span_right = 1000, stride = 5, target_dir = "" )
organism |
Organism code (default: "scerevisiae") |
model |
Biological model/system (default: "BY4741 strain") |
condition |
Experimental condition (default: "WT") |
genome_assembly |
Genome version (default: "sacCer3") |
type |
Data type ("Nanopore" = dual enzyme Single Molecule Footprinting) |
chromosome |
Chromosome ID (e.g., "chrIII") |
start |
Genomic start position (numeric/character) |
end |
Genomic end position (numeric/character) |
tr |
Track name for BigBed file resource (default: "nanopore_meth_calls") |
label |
Plot title annotation (default: "smac_seq") |
span_left |
Upstream window size from region (default: 1000) |
span_right |
Downstream window size from region (default: 1000) |
stride |
sliding window used for singal aggregation |
target_dir |
destination directory where outputs will be stored |
This function retrieves and visualizes DNA accessibility patterns from single-molecule data: - Integrates with UCSC-style track hubs via 'tr' parameter - Automatically handles coordinate conversion for dm6 genome - Implements dynamic y-axis scaling using 'fp_cap'
Saves a heatmap in pdf, png, and eps file formats. Also, occupancies are saved in a tsv file
# Basic usage with default parameters plotMethylationCallsNanopore() # Custom genomic region analysis plotMethylationCallsNanopore ( organism = "scerevisiae", model = "BY4741 strain", condition = "WT", genome_assembly = "sacCer3", type = "SMF", chromosome = "chrIII", start = 114300, end = 114600, tr = "nanopore_meth_calls", label = "smac_seq", span_left = 1000, span_right = 1000, stride = 5, target_dir = "")# Basic usage with default parameters plotMethylationCallsNanopore() # Custom genomic region analysis plotMethylationCallsNanopore ( organism = "scerevisiae", model = "BY4741 strain", condition = "WT", genome_assembly = "sacCer3", type = "SMF", chromosome = "chrIII", start = 114300, end = 114600, tr = "nanopore_meth_calls", label = "smac_seq", span_left = 1000, span_right = 1000, stride = 5, target_dir = "")
Generates heatmap of methylation calls from likes of SMAC-seq datasets. currently has data from Yeast (sacCer3)
plotMethylationCallsNanoporeUsingLocalBigBed( bigBed = "", chromosome = "chrIII", start = 114300, end = 114600, label = "smac_seq", span_left = 1000, span_right = 1000, remove_dup = FALSE, stride = 5, target_dir = "" )plotMethylationCallsNanoporeUsingLocalBigBed( bigBed = "", chromosome = "chrIII", start = 114300, end = 114600, label = "smac_seq", span_left = 1000, span_right = 1000, remove_dup = FALSE, stride = 5, target_dir = "" )
bigBed |
BigBed file path (e.g., "demo.bb") |
chromosome |
Chromosome ID (e.g., "chr2L") |
start |
Genomic start position (numeric/character) |
end |
Genomic end position (numeric/character) |
label |
Plot title annotation |
span_left |
Upstream window size from region (default: 150) |
span_right |
Downstream window size from region (default: 150) |
remove_dup |
Remove duplicate reads? (default: FALSE) |
stride |
a window size used for averaging the methylation call values |
target_dir |
destination directory where outputs will be stored |
This function uses local SMF/dSMF bigBed file and plot heatmap
Saves a methylation calls (binary) heatmap in pdf, png, and eps file formats.